/* UPDATE.CMD for installing CSD fixes */

x = setlocal()

echo = '@'

/* Read in parameters (if any), and set defaults */
ARG commandline

/* Load special REXX libraries for later use */
call rxfuncadd sysloadfuncs, rexxutil, sysloadfuncs
call sysloadfuncs

/* Enable DBCS character sets options */
OPTIONS 'ETMODE'
OPTIONS 'EXMODE'

say 'Please be aware that you will be deleting all DPF Spool'
say 'information and possibly all resource pointers by executing'
say 'this procedure.'
say ''
say 'Be sure to answer yes(y) to all of the following questions!'
say ''
say 'If you understand this, and want to continue, press ENTER.'

parse upper pull dummy

CALL INIT;

/*****************************************************************/
/* Try to Start Database Manager, 'rc' is set by Rexx and tested */
/* in a later line.                                              */
/*****************************************************************/
IF FILESTATE(psf2dir'\INSTALL\BASEPSF.PKG') <> 0 THEN DO
  rct = 1048
END
ELSE DO
  'startdbm'
  rct = rc
END
createainbase = no
createainbasedpf = no
createaindpf = no

/*****************************************************************/
/* Determine which databases need to be created                  */
/*****************************************************************/
IF ((rct = 0) | (rct = 1)) then do
  /* We know DB2/2 is present and started, next check what */
  /* databases need to be recreated.                       */
  /* First, does AINBASE need to be created?               */
  IF (FILESTATE(psf2dir'\SYSTEM\AINBASE.GRP') = 0) then do
    createainbase = yes
  end /* do */
  /* Next, is DPF installed on this machine                */
  IF (FILESTATE(psf2dir'\BIN\AINDPFHR.EXE') <> 0) then do
    createainbasedpf = yes
    createaindpf = yes
  end /* do */
end /* do */
else do
  /* We know DB/2 did not start correctly for some reason, exit */
  say 'DB2/2 did not start correctly or does not exist on this system.'
  say 'Fix DB2/2 and try again.'
  CALL QUIT;
end /* do */

/*****************************************************************/
/* Create DB2/2 databases                                        */
/*****************************************************************/
/* Create AINBASE if needed  */
IF ((createainbase = yes) | (createainbasedpf = yes)) then do
  ''psf2dir'\BIN\RLINST2.EXE 'psf2dir'\BIN  'psf2dir'\RESLIB'
end /* do */

/* Create AINDPF if needed  */
IF (createaindpf = yes) then do
  ''psf2dir'\BIN\DPF_INST.EXE 'psf2dir'\BIN  'psf2dir
end /* do */

/*****************************************************************/
/* Bind the BND files to the newly created databases.            */
/*****************************************************************/
IF (createaindpf = yes) then do
  IF FILESTATE(psf2dir'\BIN\AIN1QINS.BND') <> 0 THEN DO
    'SQLBIND 'psf2dir'\BIN\AIN1QINS.BND AINDPF /F=LOC'
    IF rc <> 0 THEN DO; CALL QUIT; END;
  END
  IF FILESTATE(psf2dir'\BIN\AIN2QSML.BND') <> 0 THEN DO
    'SQLBIND 'psf2dir'\BIN\AIN2QSML.BND AINDPF /F=LOC'
    IF rc <> 0 THEN DO; CALL QUIT; END;
  END
  IF FILESTATE(psf2dir'\BIN\AIN3QSML.BND') <> 0 THEN DO
    'SQLBIND 'psf2dir'\BIN\AIN3QSML.BND AINDPF /F=LOC'
    IF rc <> 0 THEN DO; CALL QUIT; END;
  END
  IF FILESTATE(psf2dir'\BIN\AIN3QMIG.BND') <> 0 THEN DO
    'SQLBIND 'psf2dir'\BIN\AIN3QMIG.BND AINDPF /F=LOC'
    IF rc <> 0 THEN DO; CALL QUIT; END;
  END
end /* do */

IF ((createainbase = yes) | (createainbasedpf = yes)) then do
  IF FILESTATE(psf2dir'\BIN\AIN3QRL3.BND') <> 0 THEN DO
    'SQLBIND 'psf2dir'\BIN\AIN3QRL3.BND AINLIB /F=LOC'
    IF rc <> 0 THEN DO; CALL QUIT; END;
  END
  IF FILESTATE(psf2dir'\BIN\AIN3QRL2.BND') <> 0 THEN DO
    'SQLBIND 'psf2dir'\BIN\AIN3QRL2.BND AINLIB /F=LOC'
    IF rc <> 0 THEN DO; CALL QUIT; END;
  END
  IF FILESTATE(psf2dir'\BIN\AIN3QRLB.BND') <> 0 THEN DO
    'SQLBIND 'psf2dir'\BIN\AIN3QRLB.BND AINLIB /F=LOC'
    IF rc <> 0 THEN DO; CALL QUIT; END;
  END
  IF FILESTATE(psf2dir'\BIN\AIN3LXLB.BND') <> 0 THEN DO
    'SQLBIND 'psf2dir'\BIN\AIN3LXLB.BND AINLIB /F=LOC'
    IF rc <> 0 THEN DO; CALL QUIT; END;
  END
  IF FILESTATE(psf2dir'\BIN\AIN3LDB.BND') <> 0 THEN DO
    'SQLBIND 'psf2dir'\BIN\AIN3LDB.BND AINLIB /F=LOC'
    IF rc <> 0 THEN DO; CALL QUIT; END;
  END
  IF FILESTATE(psf2dir'\BIN\AIN1LIN2.BND') <> 0 THEN DO
    'SQLBIND 'psf2dir'\BIN\AIN1LIN2.BND AINLIB /F=LOC'
    IF rc <> 0 THEN DO; CALL QUIT; END;
  END
end /* do */

/*****************************************************************/
/* Add default PSF/2 resources to AINBASE if needed.             */
/*****************************************************************/
IF (createainbase = yes) then do
  'cd 'psf2dir'\RESLIB'
   IF rc <> 0 THEN DO; CALL QUIT; END;
  'RLADD G AINBASE'
  ''psf2drv
   IF rc <> 0 THEN DO; CALL QUIT; END;
  'cd 'psf2dir'\RESLIB'
   IF rc <> 0 THEN DO; CALL QUIT; END;
  'RLADD R RESOURCE.RL /F'
   IF rc <> 0 THEN DO; CALL QUIT; END;
end /* do */

/* Tell customer we are done */
say 'PSF/2 database recreation has successfully completed.'

x = endlocal()
CALL QUIT2;

HELP:;
  say '**************************************************************';
  say '* This UPDATE command MUST be executed from the directory    *';
  say '* where the diskettes were unpacked.                         *';
  say '*                                                            *';
  say '* This command requires one parameter.                       *';
  say '*                                                            *';
  say '* The format is:                                             *';
  say '*   UPDATE <+b>                                              *';
  say '*     where <+b> is an optional parameter to keep BACKUPS    *';
  say '*     default is to NOT do BACKUPS                           *';
  say '*                                                            *';
  say '* Example:                                                   *';
  say '*   update                                                   *';
  say '*                                                            *';
  say '* This CMD file assumes that all files to be installed are   *';
  say '* in the same directory as the CMD file, and that you were   *';
  say '* in that directory when the CMD file was invoked.           *';
  say '**************************************************************';
  x = endlocal()
  CALL QUIT2;
RETURN;

FILESTATE:; parse arg fid;
  rc = LENGTH(STREAM(fid,'C','QUERY EXISTS'));
RETURN(rc);

INIT:;
  env = 'OS2ENVIRONMENT'
  psf2dir = VALUE('AINCODEPATH',,env)
  psf2drv = FILESPEC("DRIVE", psf2dir)
  psf2psys = VALUE('AINWORKPATH',,env)
  psf2bin = psf2dir'\bin'
  dpfexe = 'AINHR.EXE'
  baseexe = 'AINMAIN.EXE'
  warpsrv = 'NO'
RETURN;

QUIT:;
  /* Disable DBCS options */
  OPTIONS 'NOETMODE'
  OPTIONS 'NOEXMODE'
  /* Beep and Print informational message */
  CALL beep 523,1200
  say 'THERE IS A PROBLEM WITH THE RECREATE, EXITING!!!'
  EXIT;

QUIT2:;
  /* Disable DBCS options */
  OPTIONS 'NOETMODE'
  OPTIONS 'NOEXMODE'
  EXIT;
